@@ -62,7 +62,6 @@ import shutil
 import struct
 import asyncio
 import logging
-import binascii
 import ipaddress
 import contextlib
 import collections
@@ -97,6 +96,7 @@ reqValidLdef = s_config.getJsValidator({
         'iden': {'type': 'string', 'pattern': s_config.re_iden},
         'creator': {'type': 'string', 'pattern': s_config.re_iden},
         'lockmemory': {'type': 'boolean'},
+        'lmdb:growsize': {'type': 'integer'},
         'logedits': {'type': 'boolean', 'default': True},
         'name': {'type': 'string'},
     },
@@ -1101,7 +1101,7 @@ class Layer(s_nexus.Pusher):
     def __repr__(self):
         return f'Layer ({self.__class__.__name__}): {self.iden}'
 
-    async def __anit__(self, layrinfo, dirn, nexsroot=None, allow_upstream=True):
+    async def __anit__(self, layrinfo, dirn, nexsroot=None, allow_upstream=True, mapasync=True, maxreplaylog=10000):
 
         self.nexsroot = nexsroot
         self.layrinfo = layrinfo
@@ -1120,6 +1120,8 @@ class Layer(s_nexus.Pusher):
         self.lockmemory = self.layrinfo.get('lockmemory')
         self.growsize = self.layrinfo.get('growsize')
         self.logedits = self.layrinfo.get('logedits')
+        self.mapasync = mapasync
+        self.maxreplaylog = maxreplaylog
 
         # slim hooks to avoid async/fire
         self.nodeAddHook = None
@@ -1418,33 +1420,73 @@ class Layer(s_nexus.Pusher):
 
         logger.warning(f'...complete!')
 
+    async def _layrV5toV6(self):
+
+        sode = collections.defaultdict(dict)
+
+        logger.warning(f'Updating tagprop keys in bybuid index: {self.dirn}')
+
+        for byts, abrv in self.tagpropabrv.slab.scanByFull(db=self.tagpropabrv.name2abrv):
+
+            form, tag, prop = s_msgpack.un(byts)
+            if form is None:
+                continue
+
+            for lkey, buid in self.layrslab.scanByPref(abrv, db=self.bytagprop):
+                byts = self.layrslab.get(buid, db=self.bybuidv3)
+                if byts is not None:
+                    sode.clear()
+                    sode.update(s_msgpack.un(byts))
+
+                tpval = sode['tagprops'].pop((tag, prop), None)
+                if tpval is None:
+                    continue
+
+                if tag not in sode['tagprops']:
+                    sode['tagprops'][tag] = {}
+                sode['tagprops'][tag][prop] = tpval
+
+                self.layrslab.put(buid, s_msgpack.en(sode), db=self.bybuidv3)
+
+        self.meta.set('version', 6)
+        self.layrvers = 6
+
+        logger.warning('...complete!')
+
     async def _initLayerStorage(self):
 
         slabopts = {
             'readonly': self.readonly,
-            'max_dbs': 128,
-            'map_async': True,
             'readahead': True,
             'lockmemory': self.lockmemory,
-            'growsize': self.growsize,
+            'map_async': self.mapasync,
+            'max_replay_log': self.maxreplaylog,
+        }
+
+        if self.growsize is not None:
+            slabopts['growsize'] = self.growsize
+
+        otherslabopts = {
+            **slabopts,
+            'readahead': False,   # less-used slabs don't need readahead
+            'lockmemory': False,  # less-used slabs definitely don't get dedicated memory
         }
 
         path = s_common.genpath(self.dirn, 'layer_v2.lmdb')
         nodedatapath = s_common.genpath(self.dirn, 'nodedata.lmdb')
 
         self.layrslab = await s_lmdbslab.Slab.anit(path, **slabopts)
-        self.dataslab = await s_lmdbslab.Slab.anit(nodedatapath, map_async=True,
-                                                   readahead=False, readonly=self.readonly)
+        self.dataslab = await s_lmdbslab.Slab.anit(nodedatapath, **otherslabopts)
 
         metadb = self.layrslab.initdb('layer:meta')
         self.meta = s_lmdbslab.SlabDict(self.layrslab, db=metadb)
         if self.fresh:
-            self.meta.set('version', 5)
+            self.meta.set('version', 6)
 
         self.formcounts = await self.layrslab.getHotCount('count:forms')
 
         path = s_common.genpath(self.dirn, 'nodeedits.lmdb')
-        self.nodeeditslab = await s_lmdbslab.Slab.anit(path, readonly=self.readonly)
+        self.nodeeditslab = await s_lmdbslab.Slab.anit(path, **otherslabopts)
         self.offsets = await self.layrslab.getHotCount('offsets')
 
         self.tagabrv = self.layrslab.getNameAbrv('tagabrv')
@@ -1485,21 +1527,15 @@ class Layer(s_nexus.Pusher):
         if self.layrvers < 5:
             await self._layrV4toV5()
 
+        if self.layrvers < 6:
+            await self._layrV5toV6()
+
     async def getLayerSize(self):
         '''
         Get the total storage size for the layer.
         '''
-        totalsize = 0
-        for fpath, _, fnames in os.walk(self.dirn):
-            for fname in fnames:
-                fp = s_common.genpath(fpath, fname)
-                try:
-                    stat = os.stat(fp)
-                except OSError:  # pragma: no cover
-                    pass
-                else:
-                    totalsize += stat.st_blocks * 512
-        return totalsize
+        realsize, _ = s_common.getDirSize(self.dirn)
+        return realsize
 
     @s_nexus.Pusher.onPushAuto('layer:set')
     async def setLayerInfo(self, name, valu):
@@ -1811,6 +1847,7 @@ class Layer(s_nexus.Pusher):
 
             sode = self._getStorNode(buid)
 
+            i = 0
             changes = []
             for edit in edits:
 
@@ -1820,6 +1857,10 @@ class Layer(s_nexus.Pusher):
 
                 changes.extend(delt)
 
+                i += 1
+                if i % 100 == 0:
+                    await asyncio.sleep(0)
+
             flatedit = results.get(buid)
             if flatedit is None:
                 results[buid] = flatedit = (buid, form, [])
@@ -1829,6 +1870,8 @@ class Layer(s_nexus.Pusher):
             if changes:
                 edited = True
 
+            await asyncio.sleep(0)
+
         flatedits = list(results.values())
 
         if edited:
