@@ -66,6 +66,7 @@ TerminalPygMap = {
     'VARTOKN': p_t.Name.Variable,
     'VBAR': p_t.Punctuation,
     'WHILE': p_t.Keyword,
+    'WILDCARD': p_t.Name,
     'WORDTOKN': p_t.Literal.String,
     'YIELD': p_t.Keyword,
     '_ARRAYCONDSTART': p_t.Punctuation,
@@ -106,7 +107,7 @@ class StormLexer(pygments.lexer.Lexer):
                 yield node
 
     def get_tokens_unprocessed(self, text):
-        tree = self.parser.parse(text)
+        tree = self.parser.parse(text, start='query')
         for ltoken in self._yield_tree(tree):
             typ = TerminalPygMap[ltoken.type]
             yield ltoken.pos_in_stream, typ, ltoken.value
